..
    This file is part of hepcrawl.
    Copyright (C) 2015, 2016, 2017 CERN.

    hepcrawl is a free software; you can redistribute it and/or modify it
    under the terms of the Revised BSD License; see LICENSE file for
    more details.

.. currentmodule:: hepcrawl


What is HEPcrawl?
=================

HEPcrawl is a Scrapy (http://scrapy.org) based crawler and acts as the service
responsible for harvesting High-Energy Physics contents for INSPIRE-HEP. HEPcrawl
is periodically triggered by INSPIRE to perform harvesting from sources and HEPcrawl
then pushes JSON records back to INSPIRE ingestion workflows.

.. image:: Scrapyd-Inspire-Interaction.svg
